Contains error definitions specific to tokenization
Enums
TokenizationErrorrepresents errors that can occur during the tokenization process.
Contains error definitions specific to tokenization
TokenizationError represents errors that can occur during the tokenization process.